# Do not change this unless you want to completely by-pass Arch Linux' way
# of handling Java versions and vendors. Instead, please use script `archlinux-java`
append_path '/usr/lib/jvm/default/bin'
export PATH
